Module sqlite

Module sqlite 

Available on crate feature sqlite only.
This module handles discovery of a schema from an SQLite database. Note that only the types specified by official SQLite documentation are discovered.

Modules

defdef
discoverydiscovery
probeprobe
queryquery

Structs

Sqlite

Enums

SqliteDiscoveryError
All the errors that can be encountered when using this module

Type Aliases

DiscoveryResult
This type simplifies error handling